@@ -1,7 +1,7 @@
 package Perinci::Object::EnvResult;
 
-our $DATE = '2016-12-27'; # DATE
-our $VERSION = '0.28'; # VERSION
+our $DATE = '2021-01-02'; # DATE
+our $VERSION = '0.311'; # VERSION
 
 use 5.010;
 use strict;
@@ -97,7 +97,7 @@ Perinci::Object::EnvResult - Represent enveloped result
 
 =head1 VERSION
 
-This document describes version 0.28 of Perinci::Object::EnvResult (from Perl distribution Perinci-Object), released on 2016-12-27.
+This document describes version 0.311 of Perinci::Object::EnvResult (from Perl distribution Perinci-Object), released on 2020-01-02.
 
 =head1 SYNOPSIS
 
@@ -168,11 +168,11 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Ob
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Object>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Object>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Object>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Perinci-Object/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -188,7 +188,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
